@@ -36,7 +36,13 @@ class Nowfm(object):
         method = 'user.getrecenttracks'
         url = self.url_template + '&method={0}&limit=1&user={1}'.format(
             method, user)
-        jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
+        # jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
+        src = urllib.urlopen(url).read()
+        usrc = unicode(src, 'utf-8')
+        try:
+            jobj = json.loads(usrc)
+        except ValueError as e:
+            return None
         tracks = jobj['recenttracks']['track']
         if type(tracks) is not list:
             return None
@@ -77,7 +83,11 @@ class Nowfm(object):
         # 1つ前の曲の再生開始時刻のタイムスタンプ
         prev_start = int(prev['date']['uts'])
         # 1つ前の曲の演奏時間
-        prev_duration = int(self.get_track_info(prev)['duration']) / 1000
+        prev_info = self.get_track_info(prev)
+        if prev_info is not None:
+            prev_duration = int(prev_info['duration']) / 1000
+        else:
+            prev_duration = 0
         # 1つ前の曲の再生終了時刻のタイムスタンプ
         prev_end = prev_start + prev_duration
         # 現在の曲の再生開始時刻のタイムスタンプ
@@ -111,7 +121,14 @@ class Nowfm(object):
         else:
             url += '&track={0}&artist={1}'.format(
                 track['name'], track['artist']['#text'])
-        jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
+        # jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
+        src = urllib.urlopen(url).read()
+        usrc = unicode(src, 'utf-8')
+        try:
+            jobj = json.loads(usrc)
+        except ValueError as e:
+            return None
+
         return jobj['track']
 
     def _thread_get_track_info(self, track, ret):
